library(ggplot2)
library(plyr)

bnames <- read.csv("interesting-names.csv", stringsAsFactors = F)


# Time | Space ---------------------------------------------------------------

# Explore trends in individual names
matthew <- subset(bnames, name == "Matthew")
qplot(year, prop, data = matthew, geom = "line", group = state)
last_plot() + facet_wrap(~ state)

show_name <- function(name) {
  name <- bnames[bnames$name == name, ]
  qplot(year, prop, data = name, geom = "line", group = state)
}
show_name("Jessica")
show_name("Aaron")
show_name("Juan") + facet_wrap(~ state)

## Smoothing and indexing
qplot(year, prop, data = matthew, geom = "line", group = state) +   
  geom_smooth(aes(group = 1), se = F, size = 3)

# Smooth lines can make it easier to see trends
library(mgcv)
smooth <- function(y, x) {
  as.numeric(predict(gam(y ~ s(x))))
}

matthew <- ddply(matthew, "state", transform,
  prop_s = smooth(prop, year))

qplot(year, prop_s, data = matthew, geom = "line", group = state)

# Indexing trends can also be useful

index <- function(y, x) {
  y / y[order(x)[1]]
}

matthew <- ddply(matthew, "state", transform,
  prop_i = index(prop, year),
  prop_si = index(prop_s, year))

qplot(year, prop_i, data = matthew, geom = "line", group = state)
qplot(year, prop_si, data = matthew, geom = "line", group = state)

# Smooth and index all
qplot(year, prop, data = bnames, geom = "line", group = state, 
  alpha = I(1 / 4)) +  facet_wrap(~ name)

longterm <- ddply(bnames, c("name", "state"), function(df) {
  if (nrow(df) > 10) {
    df
  }
})
longterm <- ddply(longterm, c("name", "state"), transform,
  prop_s = smooth(prop, year))

qplot(year, prop_s, data = longterm, geom = "line", group = state, 
  alpha = I(1 / 4)) + facet_wrap(~ name)
last_plot() + facet_wrap(scales = "free_y")


# Space ----------------------------------------------------------------------

juan2000 <- subset(bnames, name == "Juan" & year == 2000)

## Choropleth map

# Turn map data into normal data frame
library(maps)
states <- map_data("state")
states$state <- state.abb[match(states$region, 
  tolower(state.name))]

# Merge and then restore original order
choropleth <- merge(juan2000, states, 
  by = "state", all.y = T)
choropleth <- choropleth[order(choropleth$order), ]

# Plot with polygons
qplot(long, lat, data = choropleth, geom = "polygon", 
  fill = prop, group = group)
  
ggplot(choropleth, aes(long, lat, group = group)) +
  geom_polygon(fill = "white", colour = "grey50") + 
  geom_polygon(aes(fill = prop))
  
## Proportional symbol map
mid_range <- function(x) mean(range(x))
centres <- ddply(states, c("state"), summarise, 
  lat = mid_range(lat), long = mid_range(long))

bubble <- merge(juan2000, centres, by = "state")
qplot(long, lat, data = bubble, 
  size = prop, colour = prop)

ggplot(bubble, aes(long, lat)) +
  geom_polygon(aes(group = group), data = states,  
    fill = NA, colour = "grey50") +
  geom_point(aes(size = prop, colour = prop))
  
# Space | Time ---------------------------------------------------------------

juan <- subset(bnames, name == "Juan")
bubble <- merge(juan, centres, by = "state")

ggplot(bubble, aes(long, lat)) +
  geom_polygon(aes(group = group), data = states, 
    fill = NA, colour = "grey50") +
  geom_point(aes(size = prop, colour = prop)) + 
  facet_wrap(~ year)
